==> webhawk-0.6.4.tar.gz: webhawk-0.6.4/README.md <==
# WebHawk

> Web Recon Framework written in Python3

## Description

![WebHawk Banner Image](https://raw.githubusercontent.com/thehackersbrain/webhawk/main/screenshots/webhawk.png?token=AIY2SQM2ACU5ZBBWXDLXCGDBMIGRG)

<br/>**WebHawk** is a Web Recon framework written in Python3 by Gaurav Raj [TheHackersbrain](https://gauravraj.tech)

Which was originally inspired by **RED_HAWK** tool which is not maintained by now.

## Version

**Webhawk 0.6.4**

## Installation

### Install using Pip3

- Create a new Python Virtual Environment
  ```bash
  python3 -m venv env
  ```
- Activate the virtualenv

  ```bash
  source env/bin/activate
  ```

- Install and Run the tool

  ```bash
  pip3 install webhawk && webhawk -h
  ```

- Oneliner
  ```bash
  python3 -m venv env && source env/bin/activate && pip3 install webhawk && webhawk -h
  ```

### Run as Python Script

- Clone this repo

  ```bash
  git clone https://github.com/thehackersbrain/webhawk.git
  ```

- change the directory

  ```bash
  cd webhawk
  ```

- Install required modules

  ```bash
  pip3 install -r requirements.txt
  ```

- Run the `main.py` script
  ```bash
  python main.py -h
  ```

Head over to the [wiki](https://github.com/thehackersbrain/webhawk/wiki) for uses and getting familiar with the tool.

## About the Author

- [Portfolio](https://gauravraj.tech/)
- [Blog](https://blog.gauravraj.tech/)
- [Github](https://github.com/thehackersbrain)
- [Twitter](https://twitter.com/thehackersbrain/)
- [LinkedIn](https://linkedin.com/in/thehackersbrain/)
- [Instagram](https://www.instagram.com/thehackersbrain/)
- [More Projects](https://github.com/thehackersbrain?tab=repositories)

==> webhawk-0.7.8.tar.gz: webhawk-0.7.8/README.md <==
# WebHawk

> Web Recon Framework written in Python3

---

[![CodeQL](https://github.com/thehackersbrain/webhawk/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/thehackersbrain/webhawk/actions/workflows/codeql-analysis.yml)

## Description

![WebHawk Banner Image](https://raw.githubusercontent.com/thehackersbrain/webhawk/main/screenshots/webhawk.png?token=AIY2SQM2ACU5ZBBWXDLXCGDBMIGRG)

<br/>**WebHawk** is a Web Recon framework written in Python3 by Gaurav Raj [TheHackersbrain](https://gauravraj.tech)

Which was originally inspired by **RED_HAWK** tool which is not maintained by now.

## Version

**Webhawk 0.7.8**

## Installation

### Install using Pip3

- Create a new Python Virtual Environment
  ```bash
  python3 -m venv env
  ```
- Activate the virtualenv

  ```bash
  source env/bin/activate
  ```

- Install and Run the tool

  ```bash
  pip3 install webhawk && webhawk -h
  ```

- Oneliner
  ```bash
  python3 -m venv env && source env/bin/activate && pip3 install webhawk && webhawk -h
  ```

### Run as Python Script

- Clone this repo

  ```bash
  git clone https://github.com/thehackersbrain/webhawk.git
  ```

- change the directory

  ```bash
  cd webhawk
  ```

- Install required modules

  ```bash
  pip3 install -r requirements.txt
  ```

- Run the `main.py` script
  ```bash
  python main.py -h
  ```

Head over to the [wiki](https://github.com/thehackersbrain/webhawk/wiki) for uses and getting familiar with the tool.

## About the Author

- [Portfolio](https://gauravraj.tech/)
- [Blog](https://blog.gauravraj.tech/)
- [Github](https://github.com/thehackersbrain)
- [Twitter](https://twitter.com/thehackersbrain/)
- [LinkedIn](https://linkedin.com/in/thehackersbrain/)
- [Instagram](https://www.instagram.com/thehackersbrain/)
- [More Projects](https://github.com/thehackersbrain?tab=repositories)
